/*
 * jOptions.java
 * Created in September 2000;  
 *
 * @author  Carol Finn
 * This class exists to store values from the FormatOptionsDlg class, 
 * a dialog box, and use them to format output coordinate Strings.
 */

package geotrans;

class jOptions {
    
    /* Separator */
    public static final char SPACE = ' ';
    public static final char SLASH = '/';
    public static final char COLON = ':';

    /* Range */
    public static final int _180_180 = 0;
    public static final int _0_360 = 1;

    /* +/- or N/S */
    public static final int HEMI = 0;
    public static final int SIGN = 1;

    /* Units */
    public static final int DEG = 0;
    public static final int DM  = 1;
    public static final int DMS = 2;

    /* Precision: 
    The '_' character stands for a decimal point. */
    public static final int MET100000 = 0;
    public static final int MET10000  = 1;
    public static final int MET1000   = 2;
    public static final int MET100    = 3;
    public static final int MET10     = 4;
    public static final int MET1    = 5;
    public static final int MET_1   = 6;
    public static final int MET_01  = 7;
    public static final int MET_001 = 8;

    private JNIEngine jniEngine = new JNIEngine();
    private JNIStrtoval jniStrtoval = new JNIStrtoval();
    
    private int units = DMS;  
    private int signHemi = HEMI;
    private int precision = MET1;
    private char separator = SPACE;
    private int range = _180_180;
    
    public jOptions() {
    }

    public jOptions(jOptions joptions) 
    {
        setOptions(joptions);
    }
    
  
    public int getUnits()
    {
        return units;
    }

    public int getSignHemi()
    {
        return signHemi;
    }

    public int getPrecision()
    {
        return precision;
    }

    public char getSeparator()
    {
        return separator;
    }

    public int getRange()
    {
        return range;
    }
  
  
    public void setUnits(int unit)
    {
        units = unit;
    }

    public void setSignHemi(int signhemi)
    {
        signHemi = signhemi;
    }

    public void setPrecision(int prec)
    {
        precision = prec;
        jniEngine.JNISetPrecision(prec);
        jniStrtoval.JNISetLatLongPrecision(prec);
    }

    public void setSeparator(char separ)
    {
        separator = separ;
        jniStrtoval.JNISetSeparator(separ);
    }

    public void setRange(int lonRange)
    {
        range = lonRange;
        jniStrtoval.JNISetLongRange(lonRange);
    }
  
    
    public boolean getUseNSEW()
    {
        if (signHemi == HEMI)
            return true;
        else
            return false;
    }
    
    public boolean getUseMinutes()
    {
        if (units != DEG)
            return true;
        else 
            return false;
    }
    
    public boolean getUseSeconds()
    {
        if (units == DMS)
            return true;
        else 
            return false;
    }
  
    public void reset(jOptions joptions)
    {
        setOptions(joptions);
        jniEngine.JNISetPrecision(joptions.precision);
        jniStrtoval.JNISetLatLongPrecision(joptions.precision);
        jniStrtoval.JNISetSeparator(joptions.separator);
        jniStrtoval.JNISetLongRange(joptions.range);
    }
    
    private void setOptions(jOptions joptions)
    {
        units = joptions.units;
        signHemi = joptions.signHemi;
        precision = joptions.precision;
        separator = joptions.separator;
        range = joptions.range;
    }        
    
} // end of class.
